%%
%% This is file `pl209.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pl209.dtx  (with options: `pl209')
%% 
%% Copyright (c) 2010 ASCII MEDIA WORKS
%% Copyright (c) 2016-2018 Japanese TeX Development Community
%% 
%% This file is part of the pLaTeX2e system (community edition).
%% -------------------------------------------------------------
%% 
%% File: pl209.dtx
\typeout{Entering pLaTeX 2.09 compatibility mode.}
\input{latex209.def}
\RequirePackage{ptrace}
\let\Rensuji\rensuji
\let\prensuji\rensuji
\def\@footnotemark{\leavevmode
  \ifhmode\edef\@x@sf{\the\spacefactor}\fi
  \ifydir\@makefnmark
  \else\hbox to\z@{\hskip-.25zw\raise2\cht\@makefnmark\hss}\fi
  \ifhmode\spacefactor\@x@sf\fi\relax}
\def\@makefnmark{\hbox{\ifydir $\m@th^{\@thefnmark}$
  \else\hbox{\yoko$\m@th^{\@thefnmark}$}\fi}}
\fontencoding{JY1}
\fontfamily{mc}
\fontsize{10}{15}
\DeclareSymbolFont{mincho}{JY1}{mc}{m}{n}
\DeclareSymbolFont{gothic}{JY1}{gt}{m}{n}
\DeclareSymbolFontAlphabet\mathmc{mincho}
\DeclareSymbolFontAlphabet\mathgt{gothic}
\SetSymbolFont{mincho}{bold}{JY1}{gt}{m}{n}
\jfam\symmincho
\DeclareRobustCommand\mc{%
    \kanjiencoding{\kanjiencodingdefault}%
    \kanjifamily{\mcdefault}%
    \kanjiseries{\kanjiseriesdefault}%
    \kanjishape{\kanjishapedefault}%
    \selectfont\mathgroup\symmincho}
\DeclareRobustCommand\gt{%
    \kanjiencoding{\kanjiencodingdefault}%
    \kanjifamily{\gtdefault}%
    \kanjiseries{\kanjiseriesdefault}%
    \kanjishape{\kanjishapedefault}%
    \selectfont\mathgroup\symgothic}
\DeclareRobustCommand\bf{\normalfont\bfseries\mathgroup\symbold\jfam\symgothic}
\DeclareRobustCommand\roman@normal{%
    \romanencoding{\encodingdefault}%
    \romanfamily{\familydefault}%
    \romanseries{\seriesdefault}%
    \romanshape{\shapedefault}%
    \selectfont\ignorespaces}
\DeclareRobustCommand\rm{\roman@normal\rmfamily\mathgroup\symoperators}
\DeclareRobustCommand\sf{\roman@normal\sffamily\mathgroup\symsans}
\DeclareRobustCommand\sl{\roman@normal\slshape\mathgroup\symslanted}
\DeclareRobustCommand\sc{\roman@normal\scshape\mathgroup\symsmallcaps}
\DeclareRobustCommand\it{\roman@normal\itshape\mathgroup\symitalic}
\DeclareRobustCommand\tt{\roman@normal\ttfamily\mathgroup\symtypewriter}
\DeclareRobustCommand\em{%
  \@nomath\em
  \ifdim \fontdimen\@ne\font>\z@\mc\rm\else\gt\it\fi}
\let\mcfam\symmincho
\let\gtfam\symgothic
\renewcommand\vpt   {\edef\f@size{\@vpt}\rm\mc}
\renewcommand\vipt  {\edef\f@size{\@vipt}\rm\mc}
\renewcommand\viipt {\edef\f@size{\@viipt}\rm\mc}
\renewcommand\viiipt{\edef\f@size{\@viiipt}\rm\mc}
\renewcommand\ixpt  {\edef\f@size{\@ixpt}\rm\mc}
\renewcommand\xpt   {\edef\f@size{\@xpt}\rm\mc}
\renewcommand\xipt  {\edef\f@size{\@xipt}\rm\mc}
\renewcommand\xiipt {\edef\f@size{\@xiipt}\rm\mc}
\renewcommand\xivpt {\edef\f@size{\@xivpt}\rm\mc}
\renewcommand\xviipt{\edef\f@size{\@xviipt}\rm\mc}
\renewcommand\xxpt  {\edef\f@size{\@xxpt}\rm\mc}
\renewcommand\xxvpt {\edef\f@size{\@xxvpt}\rm\mc}
\InputIfFileExists{pl209.cfg}{}{}
\endinput
%%
%% End of file `pl209.def'.
